@@ -24,7 +24,7 @@ class PublicationTests(EuphorieTestCase):
         self.surveygroup.evaluation_algorithm=u"dummy"
         view=self.survey.restrictedTraverse("@@publish")
         view.publish()
-        self.assertEqual(self.client.objectIds(), ["nl"])
+        self.assertEqual(set(self.client.objectIds()), set(['nl', 'api']))
         self.assertEqual(self.client.nl.objectIds(), ["dining"])
         sector=self.client.nl.dining
         self.assertEqual(sector.portal_type, "euphorie.clientsector")
