@@ -223,8 +223,14 @@ class WebHelpers(grok.View):
         if session is None:
             return None
 
-        return self.request.client.restrictedTraverse(
-                session.zodb_path.split('/'))
+        try:
+            return self.request.client.restrictedTraverse(
+                    session.zodb_path.split('/'))
+        except KeyError, e:
+            # This can happen when a survey has been unpublished while the
+            # current user still has it in his session.
+            log.error(e)
+            return None
 
     @memoize
     def survey_url(self, phase=None):
